@@ -1,5 +1,5 @@
 """Coment 1st Way"""
-def print_lol(the_list, level):
+def print_lol(the_list, level=0):
     #Comment 2nd Way
     for each_item in the_list:
         if isinstance(each_item, list):
